{% extends settings.LAYOUT.main_layout %} {% load i18n %} {% load templates %} {% block content %}
{% block history_menu %} {% comment %}

# {{ object }} {% if fields %}

{% for field in fields %}
- {% include settings.DETAIL_FIELDMAP %}
{% endfor %}

{% endif %}

{% for href, faclass, aclass, data in history_menu %} {% endfor %}
{% endcomment %} {% endblock history_menu %} {% block prev_content %} {% endblock prev_content %}

# {% trans 'Changements' %}

| {% trans 'Date' %} | {% trans 'Utilisateur' %} | {% trans 'Objet' %}
--- | --- | --- | ---
{% block history_row %} {% endblock history_row %}

{% endblock content %}